@@ -12,21 +12,16 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import logging
-
 from mistralclient.commands.v2 import base
 
 
-LOG = logging.getLogger(__name__)
-
-
 def format_list(service=None):
     columns = ('Name', 'Type')
 
     if service:
         data = (service.name, service.type)
     else:
-        data = (tuple('<none>' for _ in range(len(columns))),)
+        data = (tuple('' for _ in range(len(columns))),)
 
     return columns, data
 
