@@ -15,44 +15,43 @@
 #    under the License.
 #
 
-import json
 import logging
 import os.path
 
+from oslo_serialization import jsonutils
+
 from osc_lib.command import command
 
 from mistralclient.commands.v2 import base
+from mistralclient.commands.v2 import executions
 from mistralclient import utils
 
 LOG = logging.getLogger(__name__)
 
 
-class TaskFormatter(object):
+class TaskFormatter(base.MistralFormatter):
     COLUMNS = [
-        ('id',                      'ID'),
-        ('name',                    'Name'),
-        ('workflow_name',           'Workflow name'),
-        ('workflow_namespace',      'Workflow namespace'),
-        ('workflow_execution_id',   'Workflow Execution ID'),
-        ('state',                   'State'),
-        ('state_info',              'State info'),
-        ('created_at',              'Created at'),
-        ('updated_at',              'Updated at'),
+        ('id', 'ID'),
+        ('name', 'Name'),
+        ('workflow_name', 'Workflow name'),
+        ('workflow_namespace', 'Workflow namespace'),
+        ('workflow_execution_id', 'Workflow Execution ID'),
+        ('state', 'State'),
+        ('state_info', 'State info'),
+        ('created_at', 'Created at'),
+        ('started_at', 'Started at'),
+        ('finished_at', 'Finished at'),
+        ('duration', 'Duration', True),
     ]
 
-    COLUMN_FIELD_NAMES = list(zip(*COLUMNS))[0]
-    COLUMN_HEADING_NAMES = list(zip(*COLUMNS))[1]
-
-    @staticmethod
-    def format_list(task=None):
-        return TaskFormatter.format(task, lister=True)
-
     @staticmethod
     def format(task=None, lister=False):
         if task:
             state_info = (task.state_info if not lister
                           else base.cut(task.state_info))
 
+            duration = base.get_duration_str(task.started_at, task.finished_at)
+
             data = (
                 task.id,
                 task.name,
@@ -62,15 +61,17 @@ class TaskFormatter(object):
                 task.state,
                 state_info,
                 task.created_at,
-                task.updated_at or '<none>'
+                task.started_at or '<none>',
+                task.finished_at or '<none>',
+                duration
             )
         else:
             data = (tuple('' for _ in range(len(TaskFormatter.COLUMNS))),)
 
-        return TaskFormatter.COLUMN_HEADING_NAMES, data
+        return TaskFormatter.headings(), data
 
 
-class List(base.MistralLister):
+class List(base.MistralExecutionLister):
     """List all tasks."""
 
     def get_parser(self, prog_name):
@@ -81,43 +82,21 @@ class List(base.MistralLister):
             nargs='?',
             help='Workflow execution ID associated with list of Tasks.'
         )
-        parser.add_argument(
-            '--filter',
-            dest='filters',
-            action='append',
-            help='Filters. Can be repeated.'
-        )
-        parser.add_argument(
-            '--limit',
-            type=int,
-            help='Maximum number of tasks to return in a single result. '
-                 'limit is set to %s by default. Use --limit -1 to fetch the '
-                 'full result set.' % base.DEFAULT_LIMIT,
-            nargs='?'
-        )
-
         return parser
 
     def _get_format_function(self):
         return TaskFormatter.format_list
 
     def _get_resources(self, parsed_args):
-        if parsed_args.limit is None:
-            parsed_args.limit = base.DEFAULT_LIMIT
-
-            LOG.info(
-                "limit is set to %s by default. Set "
-                "the limit explicitly using \'--limit\', if required. "
-                "Use \'--limit\' -1 to fetch the full result set.",
-                base.DEFAULT_LIMIT
-            )
-
         mistral_client = self.app.client_manager.workflow_engine
 
         return mistral_client.tasks.list(
             parsed_args.workflow_execution,
+            marker=parsed_args.marker,
             limit=parsed_args.limit,
-            fields=TaskFormatter.COLUMN_FIELD_NAMES,
+            sort_keys=parsed_args.sort_keys,
+            sort_dirs=parsed_args.sort_dirs,
+            fields=TaskFormatter.fields(),
             **base.get_filters(parsed_args)
         )
 
@@ -155,8 +134,8 @@ class GetResult(command.Command):
         result = mistral_client.tasks.get(parsed_args.id).result
 
         try:
-            result = json.loads(result)
-            result = json.dumps(result, indent=4) + "\n"
+            result = jsonutils.loads(result)
+            result = jsonutils.dumps(result, indent=4) + "\n"
         except Exception:
             LOG.debug("Task result is not JSON.")
 
@@ -176,15 +155,22 @@ class GetPublished(command.Command):
 
     def take_action(self, parsed_args):
         mistral_client = self.app.client_manager.workflow_engine
-        result = mistral_client.tasks.get(parsed_args.id).published
+        res = mistral_client.tasks.get(parsed_args.id)
+        published = res.published
+        published_glob = res.published_global \
+            if hasattr(res, 'published_global') else None
 
         try:
-            result = json.loads(result)
-            result = json.dumps(result, indent=4) + "\n"
+            published = jsonutils.loads(published)
+            published = jsonutils.dumps(published, indent=4) + "\n"
+
+            if published_glob:
+                published_glob = jsonutils.loads(published_glob)
+                published += jsonutils.dumps(published_glob, indent=4) + "\n"
         except Exception:
             LOG.debug("Task result is not JSON.")
 
-        self.app.stdout.write(result or "\n")
+        self.app.stdout.write(published or "\n")
 
 
 class Rerun(command.ShowOne):
@@ -232,3 +218,14 @@ class Rerun(command.ShowOne):
         )
 
         return TaskFormatter.format(execution)
+
+
+class SubExecutionsLister(executions.SubExecutionsBaseLister):
+
+    def _get_format_function(self):
+        return executions.ExecutionFormatter.format_list
+
+    def _get_resources_function(self):
+        mistral_client = self.app.client_manager.workflow_engine
+
+        return mistral_client.tasks.get_task_sub_executions
