@@ -12,7 +12,8 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import mock
+from unittest import mock
+
 from oslotest import base
 from requests_mock.contrib import fixture
 
@@ -22,16 +23,18 @@ class BaseClientTest(base.BaseTestCase):
 
     def setUp(self):
         super(BaseClientTest, self).setUp()
+
         self.requests_mock = self.useFixture(fixture.Fixture())
 
 
 class BaseCommandTest(base.BaseTestCase):
     def setUp(self):
         super(BaseCommandTest, self).setUp()
+
         self.app = mock.Mock()
         self.client = self.app.client_manager.workflow_engine
 
-    def call(self, command, app_args=[], prog_name=''):
+    def call(self, command, app_args=(), prog_name=''):
         cmd = command(self.app, app_args)
 
         parsed_args = cmd.get_parser(prog_name).parse_args(app_args)
